@@ -11,14 +11,19 @@ from pathlib import Path
 from textwrap import indent
 from typing import TYPE_CHECKING, Tuple
 
-from git import Repo
+from git import Git, Repo
 from pydantic.dataclasses import dataclass
 
 from semantic_release.changelog.context import ChangelogMode, make_changelog_context
 from semantic_release.changelog.release_history import ReleaseHistory
-from semantic_release.cli import config as cli_config_module
 from semantic_release.commit_parser._base import CommitParser, ParserOptions
-from semantic_release.commit_parser.token import ParsedCommit, ParseResult
+from semantic_release.commit_parser.angular import AngularCommitParser
+from semantic_release.commit_parser.token import (
+    ParsedCommit,
+    ParsedMessageResult,
+    ParseError,
+    ParseResult,
+)
 from semantic_release.enums import LevelBump
 
 from tests.const import SUCCESS_EXIT_CODE
@@ -28,10 +33,10 @@ if TYPE_CHECKING:
     from typing import Any, Callable, Generator, Iterable, TypeVar
 
     try:
-        from typing import TypeAlias
-    except ImportError:
-        # for python 3.8 and 3.9
+        # Python 3.8 and 3.9 compatibility
         from typing_extensions import TypeAlias
+    except ImportError:
+        from typing import TypeAlias  # type: ignore[attr-defined, no-redef]
 
     from unittest.mock import MagicMock
 
@@ -39,15 +44,14 @@ if TYPE_CHECKING:
     from git import Commit
 
     from semantic_release.cli.config import RuntimeContext
-    from semantic_release.commit_parser.token import ParseError
 
     _R = TypeVar("_R")
 
-    GitCommandWrapperType: TypeAlias = cli_config_module.Repo.GitCommandWrapperType
+    GitCommandWrapperType: TypeAlias = Git
 
 
 def get_func_qual_name(func: Callable) -> str:
-    return f"{func.__module__}.{func.__qualname__}"
+    return str.join(".", filter(None, [func.__module__, func.__qualname__]))
 
 
 def assert_exit_code(
@@ -125,8 +129,8 @@ def remove_dir_tree(directory: Path | str = ".", force: bool = False) -> None:
 
 def dynamic_python_import(file_path: Path, module_name: str):
     spec = importlib.util.spec_from_file_location(module_name, str(file_path))
-    module = importlib.util.module_from_spec(spec)  # type: ignore
-    spec.loader.exec_module(module)  # type: ignore
+    module = importlib.util.module_from_spec(spec)  # type: ignore[arg-type]
+    spec.loader.exec_module(module)  # type: ignore[union-attr]
     return module
 
 
@@ -233,7 +237,7 @@ def prepare_mocked_git_command_wrapper_type(
     >>> mocked_push.assert_called_once()
     """
 
-    class MockGitCommandWrapperType(cli_config_module.Repo.GitCommandWrapperType):
+    class MockGitCommandWrapperType(Git):
         def __getattr__(self, name: str) -> Any:
             try:
                 return object.__getattribute__(self, f"mocked_{name}")
@@ -278,3 +282,21 @@ class CustomParserWithOpts(CommitParser[ParseResult, CustomParserOpts]):
 
 class IncompleteCustomParser(CommitParser):
     pass
+
+
+class CustomAngularParserWithIgnorePatterns(AngularCommitParser):
+    def parse(self, commit: Commit) -> ParsedCommit | ParseError:
+        if not (parse_msg_result := super().parse_message(str(commit.message))):
+            return ParseError(commit, "Unable to parse commit")
+
+        return ParsedCommit.from_parsed_message_result(
+            commit,
+            ParsedMessageResult(
+                **{
+                    **parse_msg_result._asdict(),
+                    "include_in_changelog": bool(
+                        not str(commit.message).startswith("chore")
+                    ),
+                }
+            ),
+        )
